pub struct AnimatedWrapper<E>where
E: IntoElement + StatefulInteractiveElement + ParentElement + FluentBuilder + Styled + 'static,{ /* private fields */ }Implementations
Sourceimpl<E: IntoElement + StatefulInteractiveElement + ParentElement + FluentBuilder + Styled + 'static> AnimatedWrapper<E>
impl<E: IntoElement + StatefulInteractiveElement + ParentElement + FluentBuilder + Styled + 'static> AnimatedWrapper<E>
Sourcepub fn transition_on_hover<T, I>(
self,
duration: Duration,
transition: I,
modifier: impl Fn(&bool, State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_on_hover<T, I>(
self,
duration: Duration,
transition: I,
modifier: impl Fn(&bool, State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Examples found in repository?
13 fn render(&mut self, _window: &mut Window, _: &mut Context<Self>) -> impl IntoElement {
14 let linear = std::sync::Arc::new(transition::general::Linear);
15
16 div()
17 .id("Hoverable2")
18 .flex()
19 .flex_col()
20 .gap_3()
21 .size(px(500.0))
22 .justify_center()
23 .items_center()
24 .child(
25 div()
26 .id("Hoverable")
27 .child("Hover over rectangle")
28 .bg(gpui::white())
29 .text_color(gpui::red())
30 .flex()
31 .text_xl()
32 .h_10()
33 .justify_center()
34 .items_center(),
35 )
36 .child(
37 div().flex().gap_2().child(
38 div()
39 .id("Hoverable1")
40 .size_16()
41 .with_transition("Hoverable1")
42 .transition_on_hover(
43 std::time::Duration::from_millis(250),
44 linear.clone(),
45 |hovered, state| {
46 if *hovered {
47 state.size_32()
48 } else {
49 state.size_16()
50 }
51 },
52 )
53 .bg(gpui::red()),
54 ),
55 )
56 }More examples
15 fn render(&mut self, _window: &mut Window, cx: &mut Context<Self>) -> impl IntoElement {
16 let linear = std::sync::Arc::new(transition::general::Linear);
17 let gradient1 = linear_gradient(
18 30.,
19 linear_color_stop(rgb(0xfccf31), 0.),
20 linear_color_stop(rgb(0xf55555), 1.),
21 );
22 let gradient2 = linear_gradient(
23 230.,
24 linear_color_stop(rgb(0xeead92), 0.),
25 linear_color_stop(rgb(0x6018dc), 1.),
26 );
27
28 div()
29 .id("Hoverable2")
30 .flex()
31 .flex_col()
32 .gap_3()
33 .size(px(500.0))
34 .justify_center()
35 .items_center()
36 .child(
37 div()
38 .id("Hoverable")
39 .child("Hover over rectangle")
40 .with_transition("Hoverable")
41 .bg(gpui::white())
42 .text_color(gpui::red())
43 .flex()
44 .text_xl()
45 .h_10()
46 .justify_center()
47 .items_center()
48 .transition_on_hover(
49 std::time::Duration::from_millis(250),
50 linear.clone(),
51 |hovered, state| {
52 if *hovered {
53 state
54 .text_bg(gpui::blue())
55 .text_color(gpui::yellow())
56 .text_lg()
57 } else {
58 state
59 .text_bg(gpui::white())
60 .text_color(gpui::black())
61 .text_xl()
62 }
63 },
64 ),
65 )
66 .child(
67 div().flex().gap_2().child(
68 div()
69 .id("Hoverable1")
70 .size_16()
71 .with_transition("Hoverable1")
72 .transition_on_hover(
73 std::time::Duration::from_millis(250),
74 linear.clone(),
75 |hovered, state| {
76 if *hovered {
77 state.bg(gpui::yellow()).opacity(0.)
78 } else {
79 state.bg(gpui::red()).opacity(1.)
80 }
81 },
82 )
83 .opacity(1.)
84 .bg(gpui::red()),
85 ),
86 )
87 .with_transition("Hoverable2")
88 .on_hover(cx.listener(|this, hovered, _, cx| {
89 this.hovered = *hovered;
90
91 // Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle.
92 // Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller.
93 // You must manually invoke a refresh or re-render to start the transition.
94 cx.notify();
95 }))
96 .transition_when(
97 self.hovered,
98 std::time::Duration::from_millis(500),
99 transition::general::EaseInExpo,
100 move |this| this.bg(gradient2),
101 )
102 .transition_on_click(
103 std::time::Duration::from_millis(500),
104 transition::general::EaseInExpo,
105 |_, state| state.bg(gpui::blue()),
106 )
107 .transition_on_hover(
108 std::time::Duration::from_millis(500),
109 transition::general::EaseInExpo,
110 move |hovered, state| {
111 if *hovered {
112 state.bg(gradient2)
113 } else {
114 state.origin()
115 }
116 },
117 )
118 .bg(gradient1)
119 }Sourcepub fn transition_on_click<T, I>(
self,
duration: Duration,
transition: I,
modifier: impl Fn(&ClickEvent, State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_on_click<T, I>(
self,
duration: Duration,
transition: I,
modifier: impl Fn(&ClickEvent, State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Examples found in repository?
15 fn render(&mut self, _window: &mut Window, cx: &mut Context<Self>) -> impl IntoElement {
16 let linear = std::sync::Arc::new(transition::general::Linear);
17 let gradient1 = linear_gradient(
18 30.,
19 linear_color_stop(rgb(0xfccf31), 0.),
20 linear_color_stop(rgb(0xf55555), 1.),
21 );
22 let gradient2 = linear_gradient(
23 230.,
24 linear_color_stop(rgb(0xeead92), 0.),
25 linear_color_stop(rgb(0x6018dc), 1.),
26 );
27
28 div()
29 .id("Hoverable2")
30 .flex()
31 .flex_col()
32 .gap_3()
33 .size(px(500.0))
34 .justify_center()
35 .items_center()
36 .child(
37 div()
38 .id("Hoverable")
39 .child("Hover over rectangle")
40 .with_transition("Hoverable")
41 .bg(gpui::white())
42 .text_color(gpui::red())
43 .flex()
44 .text_xl()
45 .h_10()
46 .justify_center()
47 .items_center()
48 .transition_on_hover(
49 std::time::Duration::from_millis(250),
50 linear.clone(),
51 |hovered, state| {
52 if *hovered {
53 state
54 .text_bg(gpui::blue())
55 .text_color(gpui::yellow())
56 .text_lg()
57 } else {
58 state
59 .text_bg(gpui::white())
60 .text_color(gpui::black())
61 .text_xl()
62 }
63 },
64 ),
65 )
66 .child(
67 div().flex().gap_2().child(
68 div()
69 .id("Hoverable1")
70 .size_16()
71 .with_transition("Hoverable1")
72 .transition_on_hover(
73 std::time::Duration::from_millis(250),
74 linear.clone(),
75 |hovered, state| {
76 if *hovered {
77 state.bg(gpui::yellow()).opacity(0.)
78 } else {
79 state.bg(gpui::red()).opacity(1.)
80 }
81 },
82 )
83 .opacity(1.)
84 .bg(gpui::red()),
85 ),
86 )
87 .with_transition("Hoverable2")
88 .on_hover(cx.listener(|this, hovered, _, cx| {
89 this.hovered = *hovered;
90
91 // Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle.
92 // Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller.
93 // You must manually invoke a refresh or re-render to start the transition.
94 cx.notify();
95 }))
96 .transition_when(
97 self.hovered,
98 std::time::Duration::from_millis(500),
99 transition::general::EaseInExpo,
100 move |this| this.bg(gradient2),
101 )
102 .transition_on_click(
103 std::time::Duration::from_millis(500),
104 transition::general::EaseInExpo,
105 |_, state| state.bg(gpui::blue()),
106 )
107 .transition_on_hover(
108 std::time::Duration::from_millis(500),
109 transition::general::EaseInExpo,
110 move |hovered, state| {
111 if *hovered {
112 state.bg(gradient2)
113 } else {
114 state.origin()
115 }
116 },
117 )
118 .bg(gradient1)
119 }Sourcepub fn on_hover(
self,
listener: impl Fn(&bool, &mut Window, &mut App) + 'static,
) -> Self
pub fn on_hover( self, listener: impl Fn(&bool, &mut Window, &mut App) + 'static, ) -> Self
Examples found in repository?
15 fn render(&mut self, _window: &mut Window, cx: &mut Context<Self>) -> impl IntoElement {
16 let linear = std::sync::Arc::new(transition::general::Linear);
17 let gradient1 = linear_gradient(
18 30.,
19 linear_color_stop(rgb(0xfccf31), 0.),
20 linear_color_stop(rgb(0xf55555), 1.),
21 );
22 let gradient2 = linear_gradient(
23 230.,
24 linear_color_stop(rgb(0xeead92), 0.),
25 linear_color_stop(rgb(0x6018dc), 1.),
26 );
27
28 div()
29 .id("Hoverable2")
30 .flex()
31 .flex_col()
32 .gap_3()
33 .size(px(500.0))
34 .justify_center()
35 .items_center()
36 .child(
37 div()
38 .id("Hoverable")
39 .child("Hover over rectangle")
40 .with_transition("Hoverable")
41 .bg(gpui::white())
42 .text_color(gpui::red())
43 .flex()
44 .text_xl()
45 .h_10()
46 .justify_center()
47 .items_center()
48 .transition_on_hover(
49 std::time::Duration::from_millis(250),
50 linear.clone(),
51 |hovered, state| {
52 if *hovered {
53 state
54 .text_bg(gpui::blue())
55 .text_color(gpui::yellow())
56 .text_lg()
57 } else {
58 state
59 .text_bg(gpui::white())
60 .text_color(gpui::black())
61 .text_xl()
62 }
63 },
64 ),
65 )
66 .child(
67 div().flex().gap_2().child(
68 div()
69 .id("Hoverable1")
70 .size_16()
71 .with_transition("Hoverable1")
72 .transition_on_hover(
73 std::time::Duration::from_millis(250),
74 linear.clone(),
75 |hovered, state| {
76 if *hovered {
77 state.bg(gpui::yellow()).opacity(0.)
78 } else {
79 state.bg(gpui::red()).opacity(1.)
80 }
81 },
82 )
83 .opacity(1.)
84 .bg(gpui::red()),
85 ),
86 )
87 .with_transition("Hoverable2")
88 .on_hover(cx.listener(|this, hovered, _, cx| {
89 this.hovered = *hovered;
90
91 // Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle.
92 // Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller.
93 // You must manually invoke a refresh or re-render to start the transition.
94 cx.notify();
95 }))
96 .transition_when(
97 self.hovered,
98 std::time::Duration::from_millis(500),
99 transition::general::EaseInExpo,
100 move |this| this.bg(gradient2),
101 )
102 .transition_on_click(
103 std::time::Duration::from_millis(500),
104 transition::general::EaseInExpo,
105 |_, state| state.bg(gpui::blue()),
106 )
107 .transition_on_hover(
108 std::time::Duration::from_millis(500),
109 transition::general::EaseInExpo,
110 move |hovered, state| {
111 if *hovered {
112 state.bg(gradient2)
113 } else {
114 state.origin()
115 }
116 },
117 )
118 .bg(gradient1)
119 }pub fn on_click( self, listener: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static, ) -> Self
Sourcepub fn transition_when<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
then: impl FnOnce(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
then: impl FnOnce(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Examples found in repository?
15 fn render(&mut self, _window: &mut Window, cx: &mut Context<Self>) -> impl IntoElement {
16 let linear = std::sync::Arc::new(transition::general::Linear);
17 let gradient1 = linear_gradient(
18 30.,
19 linear_color_stop(rgb(0xfccf31), 0.),
20 linear_color_stop(rgb(0xf55555), 1.),
21 );
22 let gradient2 = linear_gradient(
23 230.,
24 linear_color_stop(rgb(0xeead92), 0.),
25 linear_color_stop(rgb(0x6018dc), 1.),
26 );
27
28 div()
29 .id("Hoverable2")
30 .flex()
31 .flex_col()
32 .gap_3()
33 .size(px(500.0))
34 .justify_center()
35 .items_center()
36 .child(
37 div()
38 .id("Hoverable")
39 .child("Hover over rectangle")
40 .with_transition("Hoverable")
41 .bg(gpui::white())
42 .text_color(gpui::red())
43 .flex()
44 .text_xl()
45 .h_10()
46 .justify_center()
47 .items_center()
48 .transition_on_hover(
49 std::time::Duration::from_millis(250),
50 linear.clone(),
51 |hovered, state| {
52 if *hovered {
53 state
54 .text_bg(gpui::blue())
55 .text_color(gpui::yellow())
56 .text_lg()
57 } else {
58 state
59 .text_bg(gpui::white())
60 .text_color(gpui::black())
61 .text_xl()
62 }
63 },
64 ),
65 )
66 .child(
67 div().flex().gap_2().child(
68 div()
69 .id("Hoverable1")
70 .size_16()
71 .with_transition("Hoverable1")
72 .transition_on_hover(
73 std::time::Duration::from_millis(250),
74 linear.clone(),
75 |hovered, state| {
76 if *hovered {
77 state.bg(gpui::yellow()).opacity(0.)
78 } else {
79 state.bg(gpui::red()).opacity(1.)
80 }
81 },
82 )
83 .opacity(1.)
84 .bg(gpui::red()),
85 ),
86 )
87 .with_transition("Hoverable2")
88 .on_hover(cx.listener(|this, hovered, _, cx| {
89 this.hovered = *hovered;
90
91 // Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle.
92 // Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller.
93 // You must manually invoke a refresh or re-render to start the transition.
94 cx.notify();
95 }))
96 .transition_when(
97 self.hovered,
98 std::time::Duration::from_millis(500),
99 transition::general::EaseInExpo,
100 move |this| this.bg(gradient2),
101 )
102 .transition_on_click(
103 std::time::Duration::from_millis(500),
104 transition::general::EaseInExpo,
105 |_, state| state.bg(gpui::blue()),
106 )
107 .transition_on_hover(
108 std::time::Duration::from_millis(500),
109 transition::general::EaseInExpo,
110 move |hovered, state| {
111 if *hovered {
112 state.bg(gradient2)
113 } else {
114 state.origin()
115 }
116 },
117 )
118 .bg(gradient1)
119 }Sourcepub fn transition_when_with_priority<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl FnOnce(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_with_priority<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl FnOnce(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_else<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
else_fn: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_else<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
else_fn: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_else_with_priority<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
else_fn: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_else_with_priority<T, I>(
self,
condition: bool,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
else_fn: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_some<T, I, O>(
self,
option: Option<O>,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_some<T, I, O>(
self,
option: Option<O>,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_some_with_priority<T, I, O>(
self,
option: Option<O>,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_some_with_priority<T, I, O>(
self,
option: Option<O>,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_none<T, I, O>(
self,
option: &Option<O>,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_none<T, I, O>(
self,
option: &Option<O>,
duration: Duration,
transition: I,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.
Sourcepub fn transition_when_none_with_priority<T, I, O>(
self,
option: &Option<O>,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
pub fn transition_when_none_with_priority<T, I, O>(
self,
option: &Option<O>,
duration: Duration,
transition: I,
priority: AnimationPriority,
then: impl Fn(State<StyleRefinement>) -> State<StyleRefinement> + 'static,
) -> Selfwhere
T: Transition + 'static,
I: IntoArcTransition<T>,
Changes made via .when(), .when_else(), etc., do not automatically trigger the animation cycle. Unlike event-based listeners that hold and manage the App context, these declarative methods do not pass the context to the animation controller. You must manually invoke a refresh or re-render to start the transition.